@@ -1,6 +1,10 @@
-from pathlib import Path
-from dataclasses import dataclass
 import os
+from pathlib import Path
+from dataclasses import dataclass, field
+from typing import List
+from dotenv import load_dotenv, find_dotenv
+
+load_dotenv(find_dotenv())
 
 class Args:
     def __init__(self, **kwargs):
@@ -21,12 +25,13 @@ class Args:
 
 @dataclass
 class Project:
-    root: str = Path(__file__).parent
+    root: str = os.getcwd()
     name: str = 'project_name'
     data: str = 'data'
     log: str = 'logs'
-    model: str = 'checkpoint'
+    checkpoint: str = 'checkpoint'
     engine: str = 'torch'
+    override: List[str] = field(default_factory=list)    # a list of override string
 
     def __post_init__(self):
         self.ROOT = Path(os.getenv('PROJECT_ROOT', self.root))
@@ -36,10 +41,10 @@ class Project:
             self.DATAPATH = Path(self.data)
         else:
             self.DATAPATH = self.ROOT/self.data
-        if os.path.isabs(self.model):
-            self.CHECKPOINT = Path(self.model)
+        if os.path.isabs(self.checkpoint):
+            self.CHECKPOINT = Path(self.checkpoint)
         else:
-            self.CHECKPOINT = self.SAVEPATH/self.model
+            self.CHECKPOINT = self.SAVEPATH/self.checkpoint
         self.CHECKPOINT.mkdir(exist_ok=True, parents=True)
         self.DATAPATH.mkdir(exist_ok=True, parents=True)
     
